******************************************************************/
/* 1. Create a File of Husband-Wife Pairs and Last Time Together */
/*****************************************************************/
use "Individuals in Households Long", clear
/* this will record the sequence number in next year for annual data before 1997 */
/* need this in module 3 to identify those who moved out in the next year rather than in the following year */
tsset p_id year
gen f_f_seq=f.seq
/* keep if head of household */
/* will automatically be a biannual, odd-year survey because I didn't include relat for even years */
keep if (relat==10 & year>=1983) | (relat==1 & year<1983)
/* only males */
drop if fem==1
/* focus on actual married couples */
keep if seq==1
rename p_id f_p_id 
keep f_id f_p_id year f_f_seq
save "All Couples[1]", replace
use "Individuals in Households Long", clear
/* this will record the sequence number in next year for annual data before 1997 */
/* need this in module 3 to identify those who moved out in the next year rather than in the following year */
tsset p_id year
gen m_f_seq=f.seq
/* keep if "wife" */
/* will automatically be a biannual, odd-year survey because I didn't include relat for even years */
keep if ((relat==20 ) & year>=1983) | (relat==2 & year<1983)
/* only females */
drop if fem==0
/* focus on actual married couples */
keep if seq==2
rename p_id m_p_id
keep f_id m_p_id year m_f_seq
merge 1:1 f_id year using "All Couples[1]"
/* note there are heads without wives because, well, not all heads are married ! */
keep if _merge==3
egen last_year=max(year), by(f_p_id m_p_id)
sort m_p_id f_p_id year
drop if last_year==2011
keep if year==last_year
drop _merge
save "All Couples[2]", replace

/***********************************/
/* 2. Merge in Husbands then Wives */
/***********************************/
use "Individuals in Households Long", clear
rename p_id m_p_id
/* may have one individual with more than one marriage */
joinby m_p_id using "All Couples[2]", unmatched(both)
drop _merge hmarr hinc
rename (state age relat seq fem own educ f_id region winc fips hrace work p_wt) (m_state m_age m_relat m_seq m_fem m_own m_educ m_f_id m_region m_inc m_fips m_hrace m_work m_p_wt)
save "All Couples[3]", replace
use "Individuals in Households Long", clear
rename p_id f_p_id
merge 1:m f_p_id year using "All Couples[3]"
drop _merge hmarr winc
rename (state age relat seq fem own educ f_id region hinc fips hrace work p_wt) (f_state f_age f_relat f_seq f_fem f_own f_educ f_f_id f_region f_inc f_fips f_hrace f_work f_p_wt)
save "All Couples[4]", replace

/********************************************************************/
/* 3. Create Husband-Wife Data Set and Create a Two-Wave Data Set   */
/********************************************************************/
use "All Couples[4]", clear
/* could probably change these next two commands to make this a multi-year record after the initial separation */
keep if (year==last_year | year==last_year+2)
/* process year 2 */
/* remove spouses who did not move out in t+2 but who did move out in t+1*/
/* f_seq is a constant and always refers to the next wave after last_year */
/* drop if spouse has entered an institution in last_year+2 */
drop if (m_seq>=51 & m_seq<=59 & year==last_year+2) | (f_seq>=51 & f_seq<=59 & year==last_year+2)
/* drop if spouse entered an institution in first year following the last_year before 1997 */
drop if (m_f_seq>=51 & m_f_seq<=59 & year==last_year+2 & year<1999) | (f_f_seq>=51 & f_f_seq<=59 & year==last_year+2 & year<1999)
/* drop if spouse has died in last_year+2 */
drop if (m_seq>=81 & year==last_year+2) | (f_seq>=81 & year==last_year+2)
/* drop if spouse died in first year following the last_year before 1997 */
drop if (m_f_seq>=81 & year==last_year+2 & year<1999) | (f_f_seq>=81 & year==last_year+2 & year<1999)
/* drop if neither family id is unknown */
drop if f_f_id==0 & m_f_id==0
/* drop if still don't have two consecutive years */
bysort f_p_id m_p_id: keep if _N==2
sort m_p_id f_p_id year
order m_p_id f_p_id year last_year f_f_id m_f_id f_seq m_seq f_f_seq m_f_seq 
/* mark as missing data with 71 */
replace f_f_id=. if year>last_year & (f_f_id==0 | (f_seq>70 & f_f_id!=0 & f_f_id==m_f_id) | (f_f_seq>70 & f_f_id!=0 & f_f_id==m_f_id & year<1999))
replace m_f_id=. if year>last_year & (m_f_id==0 | (m_seq>70 & m_f_id!=0 & f_f_id==m_f_id) | (m_f_seq>70 & m_f_id!=0 & f_f_id==m_f_id & year<1999))
gen diff=1 if m_f_id!=f_f_id
drop if diff==. & year!=last_year
bysort f_p_id m_p_id: keep if _N==2
save "All Couples[5]", replace

/***************************************************/
/* 4. Use the cust ID Record to Link to Main File */
/***************************************************/
use "PID11", clear
/* drop if no father or mother identified */
/* is this a problem? */
drop if PID3==0 | PID17==0
gen ch_p_id=(PID1*1000)+PID2
gen m_p_id=(PID3*1000)+PID4
gen f_p_id=(PID17*1000)+PID18
keep ch_p_id m_p_id f_p_id
save "PID11x", replace
/* merge to existing sample */
use "PID11x", clear
joinby f_p_id m_p_id using "All Couples[5]", unmatched(both)
drop if _merge==1
drop _merge
/* create subsample of custless to merge back into main data set? yes -- or the merge in module 5 won't work */
save "All Couples[6]", replace
drop if ch_p_id==.
save "All Couples[7]", replace
use "All Couples[6]", clear
drop if ch_p_id!=.
save "All Couples[8]", replace

/*********************************/
/* 5. Merge cust Data into File */
/*********************************/
use "Individuals in Households Long", clear
/* remove those who died or formed their own households but keep those in institutions (should we do this with > 23 year olds?) */
keep if (seq>=1 & seq<=59)
/* remove those not born yet */
drop if age==0
rename p_id ch_p_id
rename f_id ch_f_id
rename age ch_age
keep ch_p_id year ch_f_id ch_age
merge 1:1 ch_p_id year using "All Couples[7]"
/* eliminate custren who do not match a family */
/* eliminate families who have a cust but there is no match -- hence have no data on the cust */
drop if _merge!=3
drop _merge
append using "All Couples[8]"
save "All Couples[9]", replace

/*******************************/
/* 6. Summarize Custody in T=2 */
/*******************************/
use "All Couples[9]", clear
gen m_17_rx=0
replace m_17_rx=1 if ch_age>=1 & ch_age<=17 & (ch_f_id==m_f_id) & missing(ch_f_id)==0 & missing(m_f_id)==0
replace m_17_rx=. if missing(m_f_id)==1
gen f_17_rx=0
replace f_17_rx=1 if ch_age>=1 & ch_age<=17 & (ch_f_id==f_f_id) & missing(ch_f_id)==0 & missing(f_f_id)==0
replace f_17_rx=. if missing(f_f_id)==1
gen m_17_nx=0
replace m_17_nx=1 if ch_age>=1 & ch_age<=17 & (ch_f_id!=m_f_id) & missing(ch_f_id)==0 & missing(m_f_id)==0
replace m_17_nx=. if missing(m_f_id)==1
gen f_17_nx=0
replace f_17_nx=1 if ch_age>=1 & ch_age<=17 & (ch_f_id!=f_f_id) & missing(ch_f_id)==0 & missing(f_f_id)==0
replace f_17_nx=. if missing(f_f_id)==1
gen m_23_rx=0
replace m_23_rx=1 if ch_age>=18 & ch_age<=23 & (ch_f_id==m_f_id) & missing(ch_f_id)==0 & missing(m_f_id)==0
replace m_23_rx=. if missing(m_f_id)==1
gen f_23_rx=0
replace f_23_rx=1 if ch_age>=18 & ch_age<=23 & (ch_f_id==f_f_id) & missing(ch_f_id)==0 & missing(f_f_id)==0
replace f_23_rx=. if missing(f_f_id)==1
gen m_23_nx=0
replace m_23_nx=1 if ch_age>=18 & ch_age<=23 & (ch_f_id!=m_f_id) & missing(ch_f_id)==0 & missing(m_f_id)==0
replace m_23_nx=. if missing(m_f_id)==1
gen f_23_nx=0
replace f_23_nx=1 if ch_age>=18 & ch_age<=23 & (ch_f_id!=f_f_id) & missing(ch_f_id)==0 & missing(f_f_id)==0
replace f_23_nx=. if missing(f_f_id)==1
gen m_24_rx=0
replace m_24_rx=1 if ch_age>=24 & (ch_f_id==m_f_id) & missing(ch_f_id)==0 & missing(m_f_id)==0
replace m_24_rx=. if missing(m_f_id)==1
gen f_24_rx=0
replace f_24_rx=1 if ch_age>=24 & (ch_f_id==f_f_id) & missing(ch_f_id)==0 & missing(f_f_id)==0
replace f_24_rx=. if missing(f_f_id)==1
gen m_24_nx=0
replace m_24_nx=1 if ch_age>=24 & (ch_f_id!=m_f_id) & missing(ch_f_id)==0 & missing(m_f_id)==0
replace m_24_nx=. if missing(m_f_id)==1
gen f_24_nx=0
replace f_24_nx=1 if ch_age>=24 & (ch_f_id!=f_f_id) & missing(ch_f_id)==0 & missing(f_f_id)==0
replace f_24_nx=. if missing(f_f_id)==1

/* reduce to two records per mother-father combination one for year before and one for year after */
collapse (first) last_year f_f_id m_f_id m_seq f_seq m_state m_own m_relat m_age m_fem f_state f_own f_relat f_age f_fem f_educ m_educ /// 
m_region f_region m_inc f_inc m_fips f_fips m_hrace f_hrace m_p_wt f_p_wt (max) m_17_rx f_17_rx m_17_nx f_17_nx m_23_rx f_23_rx m_23_nx f_23_nx m_24_rx f_24_rx m_24_nx f_24_nx, ///
by(year m_p_id f_p_id)
/* copy next year's custody information to this year */
sort m_p_id f_p_id year
gen m_cust17=m_17_rx[_n+1] if year==last_year & m_p_id==m_p_id[_n+1]
gen f_cust17=f_17_rx[_n+1] if year==last_year & f_p_id==f_p_id[_n+1]
gen m_ncust17=m_17_nx[_n+1] if year==last_year & m_p_id==m_p_id[_n+1]
gen f_ncust17=f_17_nx[_n+1] if year==last_year & f_p_id==f_p_id[_n+1]
gen m_cust23=m_23_rx[_n+1] if year==last_year & m_p_id==m_p_id[_n+1]
gen f_cust23=f_23_rx[_n+1] if year==last_year & f_p_id==f_p_id[_n+1]
gen m_ncust23=m_23_nx[_n+1] if year==last_year & m_p_id==m_p_id[_n+1]
gen f_ncust23=f_23_nx[_n+1] if year==last_year & f_p_id==f_p_id[_n+1]
gen m_cust24=m_24_rx[_n+1] if year==last_year & m_p_id==m_p_id[_n+1]
gen f_cust24=f_24_rx[_n+1] if year==last_year & f_p_id==f_p_id[_n+1]
gen m_ncust24=m_24_nx[_n+1] if year==last_year & m_p_id==m_p_id[_n+1]
gen f_ncust24=f_24_nx[_n+1] if year==last_year & f_p_id==f_p_id[_n+1]
/* create migration variable */
sort m_p_id f_p_id year
gen f_mig=1 if f_state!=f_state[_n+1] & year+2==year[_n+1] & f_p_id==f_p_id[_n+1] & missing(f_state)==0 & missing(f_state[_n+1])==0
replace f_mig=0 if f_state==f_state[_n+1] & year+2==year[_n+1] & f_p_id==f_p_id[_n+1] & missing(f_state)==0 & missing(f_state[_n+1])==0
gen m_mig=1 if m_state!=m_state[_n+1] & year+2==year[_n+1] & m_p_id==m_p_id[_n+1] & missing(m_state)==0 & missing(m_state[_n+1])==0
replace m_mig=0 if m_state==m_state[_n+1] & year+2==year[_n+1] & m_p_id==m_p_id[_n+1] & missing(m_state)==0 & missing(m_state[_n+1])==0
/* reduce to one record for year before separation */
keep if year==last_year
/* add relative variables */
gen d_educ=m_educ-f_educ
gen d_age=m_age-f_age
gen sh_inc=(m_inc)/(f_inc+m_inc)
replace sh_inc=1 if f_inc==0
replace sh_inc=0 if m_inc==0
replace sh_inc=.5 if f_inc==0 & m_inc==0
/* add a unique id for each couple */
gen c_id=_n
/* recode education */
recode m_educ(0/11=0) (12/15=1) (16/max=2), gen(m_educx)
recode f_educ(0/11=0) (12/15=1) (16/max=2), gen(f_educx)

save "All Couples[10]", replace

/****************/
/* 7. Make Long */
/****************/
use "All Couples[10]", clear
keep m_p_id year m_f_id m_state m_own m_age m_educ m_cust17 m_cust23 m_cust24 m_ncust17 m_ncust23 m_ncust24 m_mig d_educ d_age c_id m_educx m_region ///
m_fips m_hrace sh_inc m_inc m_p_wt
gen fem=1
rename (m_p_id m_f_id m_state m_own m_age m_educ m_cust17 m_cust23 m_cust24 m_ncust17 m_ncust23 m_ncust24 m_mig m_educx m_region m_fips m_hrace m_inc m_p_wt) ///
(p_id f_id state own age educ cust17 cust23 cust24 ncust17 ncust23 ncust24 mig educx region fips hrace inc p_wt)
save "Mothers", replace
use "All Couples[10]", clear
keep f_p_id year f_f_id  f_state f_own f_age f_educ f_cust17 f_cust23 f_cust24 f_ncust17 f_ncust23 f_ncust24 f_mig d_educ d_age c_id f_educx f_region ///
f_fips f_hrace sh_inc f_inc f_p_wt
gen fem=0
rename (f_p_id f_f_id f_state f_own f_age f_educ f_cust17 f_cust23 f_cust24 f_ncust17 f_ncust23 f_ncust24 f_mig f_educx f_region f_fips f_hrace f_inc f_p_wt) ///
(p_id f_id state own age educ cust17 cust23 cust24 ncust17 ncust23 ncust24 mig educx region fips hrace inc p_wt)
save "Fathers", replace
use "Fathers", clear
append using "Mothers"
save "All Couples[11]", replace

/***************************/
/* 8. add in state grew up */
/***************************/
use "Individuals in Households Long", clear
/* keep if head of household */
keep if (relat==10 & year>=1983) | (relat==1 & year<1983)
keep p_id year hgrew
rename hgrew g_region
save "hgrew", replace
use "Individuals in Households Long", clear
/* keep if wife */
keep if ((relat==20) & year>=1983) | (relat==2 & year<1983)
keep p_id year wgrew 
rename wgrew g_region
append using "hgrew"
sort p_id year
drop if g_region==.
duplicates drop p_id, force
drop year
merge 1:m p_id using "All Couples[11]"
keep if _merge==3
drop _merge
gen p_mig=1 if region!=g_region & missing(region)==0 & missing(g_region)==0
replace p_mig=0 if region==g_region & missing(region)==0 & missing(g_region)==0
tab p_mig
save "All Couples[12]", replace

/*********************************************/
/* 9. Adjust income for inflation (1982=100) */
/* and create relative income variable       */
/*********************************************/
use "All Couples[12]", clear
merge m:1 year using "CPI"
keep if _merge==3
replace inc=100*(inc/cpi)
drop _merge
save "All Couples[13]", replace

/**********************/
/* 10. Final Data Set */
/**********************/
use "All Couples[13]", clear
drop if age<24 | age>60
keep mig p_id c_id fem age d_age own cust17 cust23 cust24 ncust17 ncust23 ncust24 educx d_educ p_mig year region inc sh_inc hrace p_wt
sort p_id year
by p_id: gen n_div=_n
order p_id year c_id n_div
drop if n_div>1
/* add time periods -- these nicely coincide with long expansions or contraction s*/
recode year (1968/1981=0) (1982/1991=1) (1992/2001=2) (2002/2011=3), gen(period)
gen children=0 if ncust17==0 & ncust23==0 & cust17==0 & cust23==0
replace children=1 if ncust17==1 | ncust23==1 | cust17==1 | cust23==1
gen child_cat=0 if children==0
replace child_cat=1 if (cust17==1 | cust23==1) & ncust17==0 & ncust23==0
replace child_cat=2 if (ncust17==1 | ncust23==1) & cust17==0 & cust23==0
replace child_cat=3 if child_cat==.
replace sh_inc=1-sh_inc if fem==0
replace d_age=-d_age if fem==0
replace d_educ=-d_educ if fem==0
drop if mig==. | own==. | age==. | hrace==. | inc==. | p_mig==. | cust17==. | cust23==. | ncust17==. | ncust23==. | fem==. | d_age==. | d_educ==. | ///
sh_inc==. | period==. | region==.
save "All Couples[14]", replace
